/**
 * Represents a base class for control handles for selected annotations that can be moved. Control handles are typically used to resize an annotation or other operations that modify the annotation.
 * @memberof Core.Annotations
 */
class ControlHandle {
  /** Defines the color for the annotation control point. */
  static color;

  /** Defines the height of all control handles. Default is 10. */
  static handleHeight = 10;

  /** Defines the width of all control handles. Default is 10. */
  static handleWidth = 10;

  /** Defines the outline color for the annotation control point. */
  static outlineColor;

  /** Defines the height of all rotation control handles. Default is 28. */
  static rotationHandleHeight = 28;

  /** Defines the width of all rotation control handles. Default is 28. */
  static rotationHandleWidth = 28;

  /** Defines a padding for selection accuracy. Default is 1. Increase this value to make selection more forgiving. */
  static selectionAccuracyPadding = 1;

  /** Defines thickness of the annotation selection outline. Default is 3. */
  static selectionPointOutlineThickness = 3;

  /** Defines the shadow blur for the annotation control point. */
  static shadowBlur;

  /** Defines the shadow color for the annotation control point. */
  static shadowColor;

  /** Defines the offset Y position for the shadow blur for the annotation control point. */
  static shadowOffsetY;

  /**
   * Creates a new box control handle
   * @param {number} x - The x-coordinate of the upper-left point
   * @param {number} y - The y-coordinate of the upper-left point
   * @param {number} width - The width of the control handle
   * @param {number} height - The height of the control handle
   */
  constructor(x, y, width, height) {
    this.x = x;
    this.y = y;
    this.width = width;
    this.height = height;
  }

  /**
   * Draws the control handle's appearance on the provided canvas context
   * @param {CanvasRenderingContext2D} ctx - the annotation canvas context
   * @param {Core.Annotations.Annotation} annotation - the annotation to modify
   * @param {Core.Math.Rect} selectionBox - the selection rect
   * @param {number} zoom - the current zoom level of the document
   */
  draw(ctx, annotation, selectionBox, zoom) {}

  /**
   * Determines if the provided point is a hit on the control handle. See {@link Core.Annotations.SelectionAlgorithm} for usuable selection algorithms.
   * @param {Core.Annotations.Annotation} annotation - the annotation
   * @param {Core.Math.Rect} selectionBox - the selection rect
   * @param {number} zoom - the current zoom level of the document
   * @param {number} x - the x-coordinate of the point to test, in page coordinates
   * @param {number} y - the y-coordinate of the point to test, in page coordinates
   * @return {boolean} true if the provided point is a hit
   */
  testSelection(annotation, selectionBox, zoom, x, y) {}
}

export default ControlHandle;
