/**
 * @memberof Core.Annotations.Forms
 */
class FieldManager {

  /**
   * Represents a tree of PDF Forms fields. @see {Core.Annotations.Forms.Field} Allows adding, getting and visiting fields.
   * @param {Core.AnnotationManager} annotationManager 
   */
  constructor(annotationManager) {
    this.annotationManager = annotationManager;
  }

  /**
   * Adds the given field object to the field tree, either replacing or merging with any existing field. Note: if the field is merged, it is the equivalent of performing Annotations.Forms.Field.set on the existing field, followed by setting all the field's widgets' fields to the original field.
   * @param {Core.Annotations.Forms.Field|object} field - The field or field-like object to add.
   * @param {boolean} [update=false]
   * @return {Core.Annotations.Forms.Field} The field that was inserted into the field tree (may not be the field originally provided).
   */
  addField(field, update = false) {}

  /**
   * iterate over every field and check if it's required and if it has a value
   * @return {boolean} Returns True if there is no required field or all fields are filled out, false otherwise
   */
  areRequiredFieldsFilled() {}

  /**
   * Equivalent to the given field's value changing, if it was at position index in the calculation order.
   * @param {?Core.Annotations.Forms.Field} field - The field to set as source for the calculation event. May be null.
   * @param {number} [index=0] - The index at which to start running the calculation order.
   */
  calculate(field, index = 0) {}

  /**
   * Listener for field value changes.
   * @param {Core.Annotations.Forms.Field} field - The field whose value changed.
   */
  fieldChanged(field) {}

  /**
   * Calls the specified callback for each of the root fields in the document. If there is a tree of form fields, then this will only iterate over root fields. Please use Core.Annotations.Forms.Field.children and a tree traversal algorithm to traverse the fields. If you know the name of your field, you can use Core.Annotations.Forms.FieldManager.getField.
   * @param {function} callback - The function that will be called for each field. The callback is passed the field object.
   * @example
const stack = [];
fieldManager.forEachField(function(field) {
  stack.push(field); // Push root fields
});
while (stack.length > 0) {
  const current = stack.pop();
  if (current.isTerminal()) {
    // Work with terminal/leaf fields
  }
  else {
    // Traverse children
    stack = stack.concat(current.children);
  }
}
   */
  forEachField(callback) {}

  /**
   * Gets a field whose full name matches the one that is given. If No field matches, and the last part of the field name is a number, returns that index of the field's widget array.
   * @param {string} name - The full name of the field to search for.
   * @return {Core.Annotations.Forms.Field|Core.Annotations.WidgetAnnotation} The field or widget, or null if no field matches.
   */
  getField(name) {}

  /**
   * Returns an array of all field objects in the document
   * @return {Array.<Core.Annotations.Forms.Field>}
   */
  getFields() {}

  /** Invokes the available print handler to print the document Note: This method requires Embedded JavaScript to not have been disabled with Core.disableEmbeddedJavaScript */
  print() {}

  /**
   * Updates the function to be used for handling alert messages for field validation.
   * @param {function} handler - The function that will handle alert messages. It will be called with a string representing the alert message.
   */
  setAlertHandler(handler) {}

  /**
   * Set the calculation order - use this if you need changes in one field to trigger calculation events on other fields. If the name of field that is changed is before the name of another field, that other field is recalculated. If the name of the field that has changed is not in the array, all the fields named by the arrya are recalculated in order.
   * @param {Array.<string>} order - An array of field names.
   */
  setCalculationOrder(order) {}

  /** Sets the function to be used to handle the print API called by embedded PDF JavaScript */
  setPrintHandler() {}

  /**
   * Renames the field that is passed to the name passed in.
   * @param {Core.Annotations.Forms.Field|object} field - The field that should be renamed.
   * @param {string} name - The name of the field to be renamed. Cannot be blank.
   * @return {Core.Annotations.Forms.Field|Core.Annotations.WidgetAnnotation} The renamed field.
   */
  updateFieldName(field, name) {}
}