/**
 * A class that represents controls used for editing contents of a freetext annotation
 * @memberof Core.Annotations.FreeTextAnnotation
 */
class RichTextEditor {

  /**
   * Gets the Quill editor options.
   * @return {Core.Annotations.FreeTextAnnotation.RichTextEditor.QuillEditorOptions} Quill options that are currently set.
   */
  static getEditorOptions() {}

  /**
   * Sets the Quill editor options.
   * @param {Core.Annotations.FreeTextAnnotation.RichTextEditor.QuillEditorOptions} options - Quill options to be set.
   */
  static setEditorOptions(options) {}

  /** Blurs the editor. */
  blur() {}

  /**
   * Delete some content from the editor.
   * @param {number} index - the start index of the range
   * @param {number} length - the length of the range
   */
  deleteText(index, length) {}

  /**
   * Format text at the current selection. If the current selection has length of 0, then the format will be set active.
   * @param {Core.Annotations.FreeTextAnnotation.RichTextEditor.Format} format 
   * @param {Core.Annotations.FreeTextAnnotation.RichTextEditor.FormatValue} value 
   */
  format(format, value) {}

  /**
   * Gets the current contents in the editor
   * @return {string} Returns the current contents in the editor
   */
  getContents() {}
}

/**
 * The available formats of an editor instance
 * @typedef {'color' | 'bold' | 'italic' | 'underline' | 'strike'} Core.Annotations.FreeTextAnnotation.RichTextEditor.Format
 */

/**
 * The value of a format. The value should be a hex color string(e.g. #FF00FF) for the `color` format, and boolean for the rest of formats.
 * @typedef {string | boolean} Core.Annotations.FreeTextAnnotation.RichTextEditor.FormatValue
 */

/**
 * @typedef {object} Core.Annotations.FreeTextAnnotation.RichTextEditor.QuillEditorOptions
 * @property {Element} bounds - DOM Element or a CSS selector for a DOM Element, within which the editor’s UI elements (i.e. tooltips, etc.) should be confined. Currently, it only considers left and right boundaries.
 * @property {string} debug - Shortcut for debug. Note debug is a static method and will affect other instances of Quill editors on the page. Only warning and error messages are enabled by default.
 * @property {object} formats - [WARNING: this is not fully supported by WebViewer and may result in unexpected behavior] Whitelist of formats to allow in the editor. See Formats for a complete list.
 * @property {object} modules - Collection of modules to include and respective options. See Modules for more information.
 * @property {string} placeholder - Placeholder text to show when editor is empty.
 * @property {boolean} readOnly - Whether to instantiate the editor in read-only mode.
 * @property {Element} scrollingContainer - DOM Element or a CSS selector for a DOM Element, specifying which container has the scrollbars (i.e. overflow-y: auto), if is has been changed from the default ql-editor with custom CSS. Necessary to fix scroll jumping bugs when Quill is set to auto grow its height, and another ancestor container is responsible from the scrolling.
 * @property {string} theme - [WARNING: this is not fully supported by WebViewer and may result in unexpected behavior] Themes to use for the editor.
 * @property {boolean} shouldScrollContainer - Whether to scroll the container when text exceeds the Text Box.
 */