import HTMLAnnotation from './HTMLAnnotation';
/**
 * Represents an extendable Widget annotation. These annotations contain a field value
 * @memberof Core.Annotations
 */
class WidgetAnnotation extends HTMLAnnotation {

  /**
   * Creates a new instance of WidgetAnnotation.
   * @extends Core.Annotations.HTMLAnnotation
   * 
   * @property {string} fieldName - Gets the name of field associated with the widget annotation.
   * @property {?string|number} value - Gets or sets the value of the widget annotation (defaults to the field value)
   * @property {?(string|number)} defaultValue - Gets or sets the default value of the field associated with the widget annotation.
   * @property {Core.Annotations.WidgetFlags} fieldFlags - Gets the flags object of the field associated with this widget.
   * @property {Core.Annotations.WidgetFlags} flags - Gets the flags object on this widget.
   * @property {Core.Annotations.Font} font - Gets or sets the font object associated with this widget (defaults to the field's font if not set).
   * @property {object} appearances - Gets the appearances of this field (currently keys of an object).
   * @property {string} appearance - Gets or sets the widgets current appearance name.
   * @property {object} captions - Gets the map of this widget's captions. (Normal is used for the face of PushButtonAnnotations)
   * @property {function} getCustomStyles - A function that receives the widget object and should return any CSS styles that you want to override
   * @property {function} getContainerCustomStyles - A function that receives the widget object and should return any CSS styles that you want to override for its parent container
   */
  constructor(options) {
    super(options);
    this.fieldName = options?.fieldName;
    this.value = options?.value;
    this.defaultValue = options?.defaultValue;
    this.fieldFlags = options?.fieldFlags;
    this.flags = options?.flags;
    this.font = options?.font;
    this.appearances = options?.appearances;
    this.appearance = options?.appearance;
    this.captions = options?.captions;
    this.getCustomStyles = options?.getCustomStyles;
    this.getContainerCustomStyles = options?.getContainerCustomStyles;
  }
}

export default WidgetAnnotation;