const findIndex = (array: any[], value: any, comparator: Function) => {
  let start = 0
  let end = array.length
  while (start < end) {
    const middle = (start + end) >>> 1
    if (comparator(array[middle], value) <= 0) {
      start = middle + 1
    } else {
      end = middle
    }
  }
  return start
}

class PriorityQueue {
  options: {
    initialValues?: any[]
  }
  comparator: (a: any, b: any) => number
  items: any[]
  constructor(options: {
    comparator: (a: any, b: any) => number
    initialValues?: any[]
  }) {
    this.options = options
    this.comparator = options.comparator
    this.items = (options.initialValues && options.initialValues.slice()) || []
    this.items.sort(this.comparator).reverse()
  }

  // 添加一个元素到队列
  queue(value: any) {
    const index = findIndex(this.items, value, this.comparator)
    this.items.splice(index, 0, value)
  }

  // 移除队列的最后一个元素，并返回被移除的元素
  dequeue() {
    if (this.isEmpty()) {
      throw "Queue is empty"
    }

    return this.items.pop()
  }

  // 返回队列的最后一个元素
  peek() {
    if (this.isEmpty()) {
      throw "Queue is empty"
    }

    return this.items[this.items.length - 1]
  }

  // 查找元素在队列中的位置
  find(value: any) {
    const index = findIndex(this.items, value, this.comparator) - 1
    return index >= 0 && this.comparator(this.items[index], value) === 0 ? index : -1
  }

  // 移除队列中的一个元素
  remove(value: any) {
    const index = this.find(value)
    if (index >= 0) {
      this.items.splice(index, 1)
      return true
    }
    return false
  }

  // 移除队列中的匹配到的所有元素
  removeAllMatching(test: Function, callback: Function) {
    let count = 0
    for (let i = this.items.length - 1; i >= 0; i--) {
      if (test(this.items[i])) {
        const value = this.items.splice(i, 1)[0]
        if (callback) {
          callback(value)
        }
        count++
      }
    }
    return count
  }

  // 检查队列是否为空
  isEmpty(): boolean {
    return this.items.length === 0
  }

  // 返回队列的大小
  size(): number {
    return this.items.length
  }
}

export default PriorityQueue
