interface Task {
  callback: (...args: any[]) => any
  args: any[]
}

class TaskQueue {
  private taskQueue: { [id: number]: Task } = {}
  private taskId: number = 1
  private isRunning: boolean = false

  // 添加任务到队列
  addTask(callback: (...args: any[]) => any, ...args: any[]): number {
    if (typeof callback !== "function") {
      callback = new Function("".concat(callback)) as (...args: any[]) => any
    }

    // 将任务添加到队列
    this.taskQueue[this.taskId] = { callback, args }

    // 调度任务
    this.scheduleTask(this.taskId)

    // 返回任务ID并递增
    return this.taskId++
  }

  // 删除任务
  private deleteTask(taskId: number): void {
    delete this.taskQueue[taskId]
  }

  // 执行任务
  private executeTask(taskId: number): void {
    console.log('executeTask', taskId)
    if (this.isRunning) {
      setImmediate(() => this.executeTask(taskId))
    } else {
      const task = this.taskQueue[taskId]
      console.log('task', task)
      if (task) {
        this.isRunning = true
        try {
          const { callback, args } = task
          console.log('callback', callback, args.length)
          switch (args.length) {
            case 0:
              callback()
              break
            case 1:
              callback(args[0])
              break
            case 2:
              callback(args[0], args[1])
              break
            case 3:
              callback(args[0], args[1], args[2])
              break
            default:
              callback.apply(null, args)
          }
        } finally {
          this.deleteTask(taskId)
          this.isRunning = false
        }
      }
    }
  }

  // 调度任务
  private scheduleTask(taskId: number): void {
    setImmediate(() => this.executeTask(taskId))
  }
}

export default TaskQueue
