/**
 * Creates a dispatcher. A mixin that enables many different classes to construct and dispatch PDF Actions.
 * @memberof Core.Actions
 * @mixin
 */
class Dispatcher {

  constructor(documentViewer) {
    this.documentViewer = documentViewer;
    this._actions = Object.create(null);
  }

  /**
   * Add a single action to a trigger.
   * @param {string} trigger - The name of the trigger to which to add the action.
   * @param {Core.Actions.Action | object} action - The action to add, or an object representing the desired properties (including a name)
   * @param {boolean} [replace] - True if existing actions should be replaced
   */
  addAction(trigger, action, replace) {}

  /**
   * Add the actions to the dispatcher so they run on next trigger, constructing them if necessary
   * @param {object} actions - The actions to add, as an object with triggers for keys and arrays of action-describing objects for values.
   */
  addActions(actions) {}

  /**
   * Get all the actions associated with this dispatcher.
   * @return {object} The associated actions (in the same format as addActions)
   */
  getActions() {
    return this._actions;
  }

  /**
   * Get the associated DocumentViewer.
   * @returns {Core.DocumentViewer} The associated DocumentViewer instance
   */
  getDocumentViewer() {
    return this.documentViewer;
  }

  /**
   * Set the internal DocumentViewer reference, which is required for some actions to execute correctly.
   * @param {Core.DocumentViewer} documentViewer - The DocumentViewer instance
   */
  setDocumentViewer(documentViewer) {
    this.documentViewer = documentViewer;
  }
}

export default Dispatcher;