import Action from './Action';
import Dest from './Dest';
import GoTo from './Action';
import URI from './URI';
import Dispatcher from './Dispatcher';

/** 
 * The namespace for anything to do with PDF actions and action dispatch. Actions can be defined by providing a JavaScript object that has the desired properties, and a name property defining the action subtype it represents. See documentation for specific action types for allowable properties.
 * @memberof Core
 * @namespace
 */
const Actions = {
  Action,
  Dest,
  GoTo,
  URI,

  /**
   * Additional options passed to the onTriggered handler.
   * @property {Core.Actions.ActionOnTriggeredHandler} originalOnTriggered - The original onTriggered function of this action
   * @property {Core.Actions.Action} action - The action that is being triggered
   */
  OnTriggeredAdditionalOptions: {
    originalOnTriggered: null,
    action: null
  }
}
Object.assign(Actions, Dispatcher)

export default Actions;

/**
 * The onTriggered function for actions.
 * @typedef {function(Core.Annotations.Forms.Field|Core.DocumentViewer, object, Core.DocumentViewer)} Core.Actions.ActionOnTriggeredHandler
 * @param {Core.Annotations.Forms.Field|Core.DocumentViewer} target - The dispatcher to which this action is attached
 * @param {object} event - The embedded JS event that is used when executing the action
 * @param {Core.DocumentViewer} documentViewer - The DocumentViewer to use as context for the action execution
 */
function ActionOnTriggeredHandler(target, event, documentViewer) {}