import WidgetAnnotation from './WidgetAnnotation';

/**
 * Represents a Button Widget annotation, which includes push button, checkbox, and radio button.
 * @memberof Core.Annotations
 */
class ButtonWidgetAnnotation extends WidgetAnnotation {

  /**
   * An enum for each checkbox/radioButton caption values When assgin the enum to checkbox/radioButton caption, the UI of the checkbox/radioButton will be changed to the corresponded shape
   * @property {string} CROSS - name of Cross shape
   * @property {string} TICK - name of Tick shape
   * @property {string} CIRCLE - name of Circle shape
   * @property {string} DIAMAND - name of Diamand shape
   * @property {string} SQUARE - name of Square shape
   * @property {string} STAR - name of Star shape
   */
  static WidgetButtonCaptions = {
    CROSS: 'CROSS',
    TICK: 'TICK',
    CIRCLE: 'CIRCLE',
    DIAMAND: 'DIAMAND',
    SQUARE: 'SQUARE',
    STAR: 'STAR'
  }

  /**
   * Creates a new instance of ButtonWidgetAnnotation.
   * @extends Core.Annotations.WidgetAnnotation
   * 
   * @param {Core.Annotations.Forms.Field} field - The field to associate with the widget
   * @param {?object} options - A map of properties to set on the widget
   */
  constructor(field, options) {
    super(options);
    this.field = field;
  }
}

export default ButtonWidgetAnnotation;
