import Color from './Color';

/**
 * @memberof Core.Annotations
 */
class Font {

  /**
   * A class representing a PDF font.
   * @param {object} [params] - An object containing parameters to be initialised on the font.
   * 
   * @property {string} name - The font's name
   * @property {number} [size=0] - The font's size
   * @property {string} [type='Type1'] - The font's type (One of CIDType0, CIDType2, MMType1, TrueType, Type0, Type1, Type3)
   * @property {(Core.Annotations.Color|array|object)} [strokeColor=new Core.Annotations.Color([0,0,0])] - The font's stroke color
   * @property {(Core.Annotations.Color|array|object)} [fillColor=new Core.Annotations.Color([0,0,0])] - The font's fill color
   * @property {number} calculatedSize - The calculated size of the font if size is 0
   */
  constructor(params = {}) {
    this.name = params.name || '';
    this.size = params.size || 0;
    this.type = params.type || 'Type1';
    this.strokeColor = params.strokeColor || new Color([0,0,0]);
    this.fillColor = params.fillColor || new Color([0,0,0]);
    this.calculatedSize = this.size === 0 ? this.calculateSize() : this.size;
  }

  calculateSize() {
    return 14;
  }

  /**
   * Is the font solid black?
   * @return {boolean} Whether the font is solid black
   */
  isBlack() {}

  /**
   * Set all properties on Font using a Font or a Font-like object.
   * @param {Core.Annotations.Font|object} options - 	The options to set on the Font
   */
  set(options) {}

  /**
   * Convert the font to a CSS object like one would pass to jQuery.css().
   * @param {number} zoom 
   * @return {object} An object appropriate to pass to jQuery.css()
   */
  toCSS(zoom) {}
}

export default Font;
