import IPathAnnotation from './IPathAnnotation';

/**
 * @memberof Core.Annotations
 */
class FreeHandAnnotation extends IPathAnnotation {

  /**
   * Represents a FreeHand annotation.
   * @extends Core.Annotations.IPathAnnotation
   * @param {object} [initializer] - A map of values to auto-initialize certain properties of the annotation. You can only initialize properties defined on the annotation under the Members section (unless specified otherwise).
   */
  constructor(initializer) {
    super(initializer);
    
    /**
     * The topmost point of the annotation.<br/>
     * This property cannot be initialized through the initializer.
     */
    this.TopMost = null;
    
    /**
     * The leftmost point of the annotation.<br/>
     * This property cannot be initialized through the initializer.
     */
    this.LeftMost = null;
    
    /**
     * The rightmost point of the annotation.<br/>
     * This property cannot be initialized through the initializer.
     */
    this.RightMost = null;

    /**
     * The bottommost point of the annotation.<br/>
     * This property cannot be initialized through the initializer.
     */
    this.BottomMost = null;

    /** Gets or sets the intent of the freehand. */
    this.Intent = initializer?.Intent || null;

    /**
     * Whether to simplify the path points or not.
     * @default false
     */
    this.shouldSimplifyPath = false;
  }

  /**
   * Adds a point to the specified path. This method will create a new path if the specified path index is equal to the total number of existings paths, and set the x and y value as its first point.
   * @param {number} x - The x coordinate of the point
   * @param {number} y - The y coordinate of the point
   * @param {number} [pathIndex] - The index of the path, defaults to 0
   */
  addPathPoint(x, y, pathIndex) {}

  /** empty the paths in the path array. */
  emptyPaths() {}

  /**
   * Gets the specified path in the path array.
   * @param {number} [pathIndex] - The index of the path, defaults to 0
   * @return {Array.<Core.Math.Point>} The array of path points
   */
  getPath(pathIndex) {}

  /**
   * Gets the specified point in the path at the specified index.
   * @param {number} index - The index of the point in the specified path
   * @param {number} [pathIndex] - The index of the path, defaults to 0
   * @return {Core.Math.Point} The path point as an object with x and y properties
   */
  getPathPoint(index, pathIndex) {}

  /**
   * Gets the array of paths for this annotation.
   * @return {Array} an array of paths, where a path is an array of Annotation.Points
   */
  getPaths() {}

  /**
   * Removes the last point from the specified path.
   * @param {number} pathIndex - The index of the path, defaults to 0
   * @return {Core.Math.Point} The point that was removed from the path.
   */
  popPath(pathIndex) {}

  /**
   * Sets a path in the path array.
   * @param {Array.<Core.Math.Point>} path - An array of Annotation.Point objects.
   * @param {number} pathIndex - The index of the path, defaults to 0
   */
  setPath(path, pathIndex) {}

  /**
   * Sets a point at the specified path. This method will create a new path if the specified path index is equal to the total number of existings paths, and set the x and y value as its first point.
   * @param {number} index - The index in the path array to set
   * @param {number} x - The x coordinate of the point
   * @param {number} y - The y coordinate of the point
   * @param {number} [pathIndex] - The index of the path, defaults to 0
   */
  setPathPoint(index, x, y, pathIndex) {}
}

export default FreeHandAnnotation;
