import Annotation from './Annotation';
import Color from './Color';
import Border from './Border';

/**
 * @memberof Core.Annotations
 * @mixes Core.Actions.Dispatcher
 */
class HTMLAnnotation extends Annotation {

  /**
   * An common base class annotation that displays its contents using HTML5 instead of via Canvas.
   * @extends Core.Annotations.Annotation
   * 
   * @property {Object} rect - The annotation's rectangle
   * @property {?Element} element - Gets the annotation's outer display element, if it exists
   * @property {?Element} innerElement - Gets the annotation's inner UI element, if it exists
   * @property {boolean} [hidden=false] - Gets and sets whether the annotation is hidden
   * @property {Core.Annotations.Color|object|Array.<any>} [color=new Core.Annotations.Color()] - Gets and sets the annotation's color (any type that can be used to construct Core.Annotations.Color)
   * @property {Core.Annotations.Border|object} [border=new Core.Annotations.Border()] - Gets and sets the annotation's border (is a border, or a map of border properties)
   * @property {Core.Annotations.Color|object|Array.<any>} [backgroundColor=new Core.Annotations.Color()] - Gets and sets the annotation's background color
   * @property {Object} [actions={}] - Gets the actions attached to this annotation as an object with triggers as keys and arrays of actions as values
   * @property {number} [rotation={}] - Gets and sets the annotation's rotation (must be one of 0, 90, 180, 270)
   */
  constructor(options) {
    super(options);
    this.rect = options?.rect || {};
    this.element = options?.element || null;
    this.innerElement = options?.innerElement || null;
    this.hidden = options?.hidden || false;
    this.color = options?.color || new Color();
    this.border = options?.border || new Border();
    this.backgroundColor = options?.backgroundColor || new Color();
    this.actions = options?.actions || {};
    this.rotation = options?.rotation || {};
  }
}

export default HTMLAnnotation;
