import MarkupAnnotation from './MarkupAnnotation';
import Point from '../Math/Point';

/**
 * @memberof Core.Annotations
 */
class IPathAnnotation extends MarkupAnnotation {

  /**
   * An abstract annotation class for aiding the creation of path-based annotations. Classes extending IPathAnnotation or implements the interface can be used by the PathTools. Note: this class makes no assumptions on serialization
   * @extends Core.Annotations.MarkupAnnotation
   * @param {object} [initializer] - A map of values to auto-initialize certain properties of the annotation. You can only initialize properties defined on the annotation under the Members section (unless specified otherwise).
   */
  constructor(initializer) {
    super(initializer);
    this.path = [];
  }

  /**
   * Adds a point to the path
   * @param {number} x - The x coordinate of the point
   * @param {number} y - The y coordinate of the point
   */
  addPathPoint(x, y) {
    this.path.push(new Point(x, y));
  }

  /** Recalculate the width and height of the annotation */
  adjustRect() {}

  /**
   * Gets the path array
   * @return {Array.<Core.Math.Point>} The array of path points
   */
  getPath() {
    return this.path;
  }

  /**
   * Gets the point in the path at the specified index
   * @param {number} index - The index in the path array
   * @return {object} The path point as an object with x and y properties
   */
  getPathPoint(index) {
    return this.path[index];
  }

  /**
   * Removes the last point from the path
   * @return {object} The path point as an object with x and y properties
   */
  popPath() {
    this.path.pop();
  }

  /**
   * Sets the path point at a specific index
   * @param {number} index - The index in the path array to set
   * @param {number} x - The x coordinate of the point
   * @param {number} y - The y coordinate of the point
   */
  setPathPoint(index, x, y) {
    this.path[index].x = x;
    this.path[index].y = y;
  }
}

export default IPathAnnotation;
