import Annotation from './Annotation.js';
import Color from './Color.js';

/**
 * Represents an extendable Markup annotation. These annotations may optionally include a fill color, stroke color, and stroke thickness.
 * @memberof Core.Annotations
 */
class MarkupAnnotation extends Annotation {

  /**
   * Creates a new instance of MarkupAnnotation.
   * @extends Core.Annotations.Annotation
   * @param {object} [initializer] - A map of values to auto-initialize certain properties of the annotation. You can only initialize properties defined on the annotation under the Members section (unless specified otherwise).
   */
  constructor(initializer) {
    super(initializer);

    /** Gets or sets the date the annotation was created. */
    this.DateCreated = initializer?.DateCreated || new Date();

    /** Gets or sets the color of the annotation's interior. */
    this.FillColor = initializer?.FillColor || new Color(0, 0, 0, 1);

    /** Gets or sets the opacity of the annotation. */
    this.Opacity = initializer?.Opacity || 0.5;

    /** Gets or sets the color of the annotation's stroke. */
    this.StrokeColor = initializer?.StrokeColor || new Color(0, 0, 0, 1);

    /** Gets or sets the width of the annotation's stroke outline. */
    this.StrokeThickness = initializer?.StrokeThick || 1;
  }
}

export default MarkupAnnotation;
