import WidgetAnnotation from './WidgetAnnotation.js'

/**
 * Represents a Signature Widget annotation.
 * @memberof Core.Annotations
 */
class SignatureWidgetAnnotation extends WidgetAnnotation {

  /**
   * Creates a new instance of SignatureWidgetAnnotation.
   * @extends Core.Annotations.WidgetAnnotation
   * 
   * @param {Core.Annotations.Forms.Field} field - The field to associate with the widget
   * @param {object} [options] - A map of properties to set on the widget
   * 
   * @property {function} createSignHereElement - A function that creates the sign here element in the annotation. This can be replaced with your own function.
   * @property {object} annot - The annotation associated with the signature widget.
   */
  constructor(field, options) {
    super(options);
    this.field = field;
    this.createSignHereElement = options?.createSignHereElement;

    /** Get or set the annotation associated with the signature widget. */
    this.annot = options?.annot;
  }

  /**
   * Removes a signature from a signed signature widget and redraws it
   * @param {Core.AnnotationManager} annotationManager - A reference to the annotation manager used to redraw the signature widget
   */
  clearSignature(annotationManager) {}

  /**
   * Signs the signature widget by adding a custom appearance from an annotation
   * @param {Core.Annotations.FreeHandAnnotation|Core.Annotations.StampAnnotation} annotation - a freehand annotation or a stamp annotation to create the appearance from
   * @param {Core.AnnotationManager} annotationManager - A reference to the annotation manager used to add the appearance
   */
  createSignatureAppearance(annotation, annotationManager) {}

  /**
   * Get the annotation associated with the signature widget.
   * @return {Core.Annotations.FreeHandAnnotation|Core.Annotations.StampAnnotation} the annotation associated with the signature widget.
   */
  getAssociatedSignatureAnnotation() {}

  /**
   * Returns a boolean value indicating whether the signature widget has been signed by an appearance
   * @return {boolean} Whether or not the signature widget has a signature appearance
   */
  isSignedByAppearance() {}

  /**
   * Returns a promise that will be resolved with a boolean value indicating whether the signature widget is signed digitally by default
   * @return {Promise.<any>}
   */
  isSignedDigitally() {}

  /**
   * Returns true if the Widget is setup to take Initials
   * @return {boolean} Boolean representing whether this widget is setup for initials or signatures. Based on this flag it will either render the "Sign Here" text handler or "Initials"
   */
  requiresInitials() {}

  /**
   * Get the annotation associated with the signature widget.
   * @param {Core.Annotations.FreeHandAnnotation | Core.Annotations.StampAnnotation} associatedSignatureAnnotation - a freehand annotation or a stamp annotation 
   */
  setAssociatedSignatureAnnotation(associatedSignatureAnnotation) {}

  /**
   * Signs a signature widget by adding a signature annotation that is rotated and resized accordingly.
   * @param {Core.Annotations.FreeHandAnnotation | Core.Annotations.StampAnnotation} signature - a freehand annotation or a stamp annotation to sign with.
   */
  sign(signature) {}
}

export default SignatureWidgetAnnotation;
