import MarkupAnnotation from './MarkupAnnotation.js'

/**
 * @memberof Core.Annotations
 */
class StampAnnotation extends MarkupAnnotation {

  /**
   * Represents the different stamp icon names that you can use in the useStamp function of RubberStampCreateTool.
   * @property {string} APPROVED - Stamp shows Approved
   * @property {string} AS_IS - Stamp shows As Is
   * @property {string} COMPLETED - Stamp shows Completed
   * @property {string} CONFIDENTIAL - Stamp shows Confidential
   * @property {string} DEPARTMENTAL - Stamp shows Departmental
   * @property {string} DRAFT - Stamp shows Draft
   * @property {string} EXPERIMENTAL - Stamp shows Experimental
   * @property {string} EXPIRED - Stamp shows Expired
   * @property {string} FINAL - Stamp shows Final
   * @property {string} FOR_COMMENT - Stamp shows For Comment
   * @property {string} FOR_PUBLIC_RELEASE - Stamp shows For Public Release
   * @property {string} INFORMATION_ONLY - Stamp shows Information Only
   * @property {string} NOT_APPROVED - Stamp shows Not Approved
   * @property {string} NOT_FOR_PUBLIC_RELEASE - Stamp shows Not For Public Release
   * @property {string} PRELIMINARY_RESULTS - Stamp shows Preliminary Results
   * @property {string} SB_REJECTED - Stamp shows Rejected
   * @property {string} SH_ACCEPTED - Stamp shows Accepted
   * @property {string} SH_INITIAL_HERE - Stamp shows Initial Here
   * @property {string} SH_SIGN_HERE - Stamp shows Sign Here
   * @property {string} SH_WITNESS - Stamp shows Witness
   * @property {string} SOLD - Stamp shows Sold
   * @property {string} TOP_SECRET - Stamp shows Top Secret
   * @property {string} VOID - Stamp shows Void
   */
  static IconNames = {
    APPROVED: 'APPROVED',
    AS_IS: 'AS_IS',
    COMPLETED: 'COMPLETED',
    CONFIDENTIAL: 'CONFIDENTIAL',
    DEPARTMENTAL: 'DEPARTMENTAL',
    DRAFT: 'DRAFT',
    EXPERIMENTAL: 'EXPERIMENTAL',
    EXPIRED: 'EXPIRED',
    FINAL: 'FINAL',
    FOR_COMMENT: 'FOR_COMMENT',
    FOR_PUBLIC_RELEASE: 'FOR_PUBLIC_RELEASE',
    INFORMATION_ONLY: 'INFORMATION_ONLY',
    NOT_APPROVED: 'NOT_APPROVED',
    NOT_FOR_PUBLIC_RELEASE: 'NOT_FOR_PUBLIC_RELEASE',
    PRELIMINARY_RESULTS: 'PRELIMINARY_RESULTS',
    SB_REJECTED: 'SB_REJECTED',
    SH_ACCEPTED: 'SH_ACCEPTED',
    SH_INITIAL_HERE: 'SH_INITIAL_HERE',
    SH_SIGN_HERE: 'SH_SIGN_HERE',
    SH_WITNESS: 'SH_WITNESS',
    SOLD: 'SOLD',
    TOP_SECRET: 'TOP_SECRET',
    VOID: 'VOID'
  }

  /**
   * Represents a stamp annotation.
   * @extends Core.Annotations.MarkupAnnotation
   * @param {object} [initializer] - A map of values to auto-initialize certain properties of the annotation. You can only initialize properties defined on the annotation under the Members section (unless specified otherwise).
   */
  constructor(initializer) {
    super(initializer);

    /** Gets or sets the type of the stamp. */
    this.Icon = initializer?.Icon;
  }

  /**
   * Asynchronously returns the image data URL
   * @return {Promise.<string>} a promise that resolves to the image data URL
   */
  getImageData() {}

  /**
   * If this instance of a Stamp Annotation was originally created with a URL in WebViewer, the corresponding URL will be returned
   * @return {string} The URL where this stamp originated from
   */
  getOriginalURL() {}

  /**
   * Gets the stamp's text
   * @returns {string}
   */
  getStampText() {}

  /**
   * Asynchronously sets the image URL of the stamp annotation
   * @param {string} imageDataUrl - the data URL of the image
   * @param {boolean} [keepAsSVG=false] - If image is an SVG data URL then by default it will be converted to PNG to work with other PDF viewers. If this parameter is true then it will not be converted and remain as SVG but will not be visible in other PDF viewers after downloading.
   * @return {Promise.<void>} a promise that resolves when the image data URL has been set
   */
  setImageData(imageDataUrl, keepAsSVG) {}

  /**
   * Sets the stamp's text
   * @param {string} text 
   */
  setStampText(text) {}
}

export default StampAnnotation;
