import MarkupAnnotation from './MarkupAnnotation.js'

/**
 * @memberof Core.Annotations
 */
class StickyAnnotation extends MarkupAnnotation {

  /**
   * An enum with possible icon names.
   * @property {string} INSERT
   * @property {string} CIRCLE
   * @property {string} NEW_PARAGRAPH
   * @property {string} HELP
   * @property {string} KEY
   * @property {string} CHECK
   * @property {string} CHECKMARK
   * @property {string} CROSS
   * @property {string} CROSS_HAIRS
   * @property {string} PARAGRAPH
   * @property {string} RIGHT_ARROW
   * @property {string} RIGHT_POINTER
   * @property {string} STAR
   * @property {string} UP_ARROW
   * @property {string} UP_LEFT_ARROW
   * @property {string} COMMENT
   */
  static IconNames = {
    INSERT: 'Insert',	
    CIRCLE: 'Circle',	
    NEW_PARAGRAPH: 'NewParagraph',	
    HELP: 'Help',	
    KEY: 'Key',	
    CHECK: 'Check',	
    CHECKMARK: 'Checkmark',	
    CROSS: 'Cross',	
    CROSS_HAIRS: 'CrossHairs',	
    PARAGRAPH: 'Paragraph',	
    RIGHT_ARROW: 'RightArrow',	
    RIGHT_POINTER: 'RightPointer',	
    STAR: 'Star',	
    UP_ARROW: 'UpArrow',	
    UP_LEFT_ARROW: 'UpLeftArrow',	
    COMMENT: 'Comment'
  }

  /** The size of the width and height of all sticky annotations */
  static SIZE = 10;

  /**
   * Represents a sticky annotation.
   * @extends Core.Annotations.MarkupAnnotation
   * @param {object} [initializer] - A map of values to auto-initialize certain properties of the annotation. You can only initialize properties defined on the annotation under the Members section (unless specified otherwise).
   */
  constructor(initializer) {
    super(initializer);

    /** The name of the icon to use for this sticky annotation. */
    this.Icon = initializer?.Icon || 'Comment';

    /** Gets or sets the state of the annotation. Annotations may have an author-specific state associated with them. State include: Accepted, Rejected, Cancelled, Completed, None. */
    this.State = initializer?.State;

    /** Gets or sets the statemodel of the annotation. Statemodel has two statemodels: Marked, Review. Under Marked, state expands to: Marked, Unmarked. */
    this.StateModel = initializer?.StateModel;

    this.elementName = 'text';
  }

  /**
   * Gets the state of the annotation.
   * @return {string} the state of the annotation.
   */
  getState() {
    return this.State;
  }

  /**
   * Set the state of the annotation.
   * @param {string} state - the state of the annotation.
   */
  setState(state) {
    this.State = state;
  }

  /**
   * Gets the statemodel of the annotation.
   * @return {string} the statemodel of the annotation.
   */
  getStateModel() {
    return this.StateModel;
  }

  /**
   * Set the statemodel of the annotation.
   * @param {string} stateModel - the statemodel of the annotation.
   */
  setStateModel(stateModel) {
    this.StateModel = stateModel;
  }
}

export default StickyAnnotation;
