/**
 * @memberof Core.Annotations
 */
class XFDFUtils {
  /** The namespace for utility functions for XFDF serialization and deserialization. */
  constructor() {}

  /**
   * Deserializes a fringe rect string into a rect object.
   * @param {string} rectString - Rect in string format.
   * @param {Core.Math.Matrix} pageMatrix - Object representing the transformation matrix for the page.
   * @param {string} separator - Separator used for coordinates. Defaults to ',' if not defined.
   * @return {Core.Math.Rect} New Rect with the x and y coordinates.
   */
  static deserializeFringeRect(rectString, pageMatrix, separator) {}

  /**
   * Deserializes the measure XML element into a measure object.
   * @param {Element} measureDictionary - Measure element.
   * @return {object} Object with measure information.
   */
  static deserializeMeasure(measureDictionary) {}

  /**
   * Deserializes a point string into a point object.
   * @param {string} pointString - Point in string format.
   * @param {Core.Math.Matrix} pageMatrix - Object representing the transformation matrix for the page.
   * @param {string} coordinateSeparator - Separator used for coordinates. Defaults to ',' if not defined.
   * @return {Core.Math.Point} New Point with with an x and y coordinate.
   */
  static deserializePoint(pointString, pageMatrix, coordinateSeparator) {}

  /**
   * Deserializes a list of points in string format into a point array.
   * @param {string} pointArrayText - Array of points in string (delimited by pointSeparator).
   * @param {Core.Math.Matrix} pageMatrix - Object representing the transformation matrix for the page.
   * @param {string} coordinateSeparator - Separator used for coordinates. Defaults to ',' if not defined.
   * @param {string} pointSeparator - Separator used for points. Defaults to ';' if not defined.
   * @return {Array.<Core.Math.Point>} Array of Points.
   */
  static deserializePointArray(pointArrayText, pageMatrix, coordinateSeparator, pointSeparator) {}

  /**
   * Deserializes a rect string into a rect object.
   * @param {string} rectString - Rect in string format. Default value '0,0,0,0'.
   * @param {Core.Math.Matrix} pageMatrix - Object representing the transformation matrix for the page.
   * @param {string} separator - Separator used for coordinates. Defaults to ',' if not defined.
   * @return {Core.Math.Rect} New Rect with the x and y coordinates.
   */
  static deserializeRect(rectString, pageMatrix, separator) {}

  /**
   * Parses a default appearance string from an XFDF file and returns an object representing the appearance.
   * @param {string} da - Appearance information in string format.
   * @return {object} Appearance information in object format.
   * @example
const data = "0 0 0 rg /Helvetica 40 Tf";
const response = Annotations.XFDFUtils.parseDefaultAppearance(data);

Output:
{
  color: "#000000",
  font: {
    name: "Arial",
    rawName: "Helvetica",
    size: "40pt",
  },
  str: "0 0 0 rg /Helvetica 40 Tf",
}
   */
  static parseDefaultAppearance(da) {}

  /**
   * Serializes a fringe rect object into a string suitable for an XFDF file.
   * @param {Core.Math.Rect} rect - Rect with the x and y coordinates.
   * @param {Core.Math.Matrix} pageMatrix - Object representing the transformation matrix for the page.
   * @param {string} separator - Separator used for coordinates. Defaults to ',' if not defined.
   * @return {string} Rect in string format.
   */
  static serializeFringeRect(rect, pageMatrix, separator) {}

  /**
   * Serializes the measure object into a measure XML element.
   * @param {object} measureDictionary - Object with measure information.
   * @param {array} measureDictionary.area - Area
   * @param {array} measureDictionary.axis - Axis
   * @param {array} measureDictionary.distance - Distance
   * @param {array} measureDictionary.scale - Scale
   * @return {Element} Return element.
   */
  static serializeMeasure(measureDictionary) {}

  /**
   * Serializes the point into a string suitable for an XFDF file.
   * @param {Core.Math.Point} point - Point with an x and y coordinate.
   * @param {Core.Math.Matrix} pageMatrix - Object representing the transformation matrix for the page.
   * @param {string} coordinateSeparator - Separator used for coordinates. Defaults to ',' if not defined.
   * @return {string} Point in string format.
   */
  static serializePoint(point, pageMatrix, coordinateSeparator) {}

  /**
   * Seriarlize the array of points into a string suitable for an XFDF file.
   * @param {Array.<Core.Math.Point>} pointArray - Array of points.
   * @param {Core.Math.Matrix} pageMatrix - Object representing the transformation matrix for the page.
   * @param {string} coordinateSeparator - Separator used for coordinates. Defaults to ',' if not defined.
   * @param {string} pointSeparator - Separator used for points. Defaults to ';' if not defined.
   * @return {string} Stringified array of points.
   */
  static serializePointArray(pointArray, pageMatrix, coordinateSeparator, pointSeparator) {}

  /**
   * Serializes a rect object into a string suitable for an XFDF file.
   * @param {Core.Math.Rect} rect - Rect with the x and y coordinates.
   * @param {Core.Math.Matrix} pageMatrix - Object representing the transformation matrix for the page.
   * @param {string} separator - Separator used for coordinates. Defaults to ',' if not defined. 
   * @return {string} Rect in string format.
   */
  static serializeRect(rect, pageMatrix, separator) {}

  /**
   * Convert a JavaScript date object into a string date that can be used in XFDF
   * @param {Date} date - Date object.
   * @return {string} Date in string format.
   */
  static toXMLDate(date) {}
}

export default XFDFUtils;
