import Annotation from './Annotation';
import Border from './Border';
import BoxControlHandle from './BoxControlHandle';
import BoxSelectionModel from './BoxSelectionModel';
import ButtonWidgetAnnotation from './ButtonWidgetAnnotation';
import CheckButtonWidgetAnnotation from './CheckButtonWidgetAnnotation';
import ChoiceWidgetAnnotation from './ChoiceWidgetAnnotation';
import Color from './Color';
import ControlHandle from './ControlHandle';
import EllipseAnnotation from './EllipseAnnotation';
import Font from './Font';
import Forms from './Forms';
import FreeHandAnnotation from './FreeHandAnnotation';
import FreeTextAnnotation from './FreeTextAnnotation';
import FreeTextSelectionModel from './FreeTextSelectionModel';
import HTMLAnnotation from './HTMLAnnotation';
import IPathAnnotation from './IPathAnnotation';
import LineAnnotation from './LineAnnotation';
import Link from './Link';
import ListWidgetAnnotation from './ListWidgetAnnotation';
import MarkupAnnotation from './MarkupAnnotation';
import RadioButtonWidgetAnnotation from './RadioButtonWidgetAnnotation';
import RectangleAnnotation from './RectangleAnnotation';
import SelectionModel from './SelectionModel';
import SignatureWidgetAnnotation from './SignatureWidgetAnnotation';
import StampAnnotation from './StampAnnotation';
import StickyAnnotation from './StickyAnnotation';
import TextHighlightAnnotation from './TextHighlightAnnotation';
import TextMarkupAnnotation from './TextMarkupAnnotation';
import TextSelectionModel from './TextSelectionModel';
import TextSquigglyAnnotation from './TextSquigglyAnnotation';
import TextStrikeoutAnnotation from './TextStrikeoutAnnotation';
import TextUnderlineAnnotation from './TextUnderlineAnnotation';
import WidgetAnnotation from './WidgetAnnotation';
import WidgetFlags from './WidgetFlags';
import XFDFUtils from './XFDFUtils';

/** 
 * The namespace for anything to do with PDF annotations.
 * @memberof Core
 * @namespace
 */
const Annotations = {
  Annotation,
  Border,
  BoxControlHandle,
  BoxSelectionModel,
  ButtonWidgetAnnotation,
  CheckButtonWidgetAnnotation,
  ChoiceWidgetAnnotation,
  Color,
  ControlHandle,
  EllipseAnnotation,
  Font,
  Forms,
  FreeHandAnnotation,
  FreeTextAnnotation,
  FreeTextSelectionModel,
  HTMLAnnotation,
  IPathAnnotation,
  LineAnnotation,
  Link,
  ListWidgetAnnotation,
  MarkupAnnotation,
  RadioButtonWidgetAnnotation,
  RectangleAnnotation,
  SelectionModel,
  SignatureWidgetAnnotation,
  StampAnnotation,
  StickyAnnotation,
  TextHighlightAnnotation,
  TextMarkupAnnotation,
  TextSelectionModel,
  TextSquigglyAnnotation,
  TextStrikeoutAnnotation,
  TextUnderlineAnnotation,
  WidgetAnnotation,
  WidgetFlags,
  XFDFUtils,

  /**
   * An enum representing different line end types that are available for line annotations
   * @property {string} NONE - No line endings
   * @property {string} OPEN_ARROW - an arrow that points outward
   * @property {string} R_OPEN_ARROW - an arrow that points inward
   * @property {string} CLOSED_ARROW - a triangle that points outward
   * @property {string} R_CLOSED_ARROW - a triangle that points inward
   * @property {string} BUTT - a vertical line
   * @property {string} SQUARE - a square
   * @property {string} DIAMOND - a diamond
   * @property {string} CIRCLE - a circle
   * @property {string} SLASH - a slash
   */
  LineEndType: {
    NONE: 'NONE',
    OPEN_ARROW: 'OPEN_ARROW',
    R_OPEN_ARROW: 'R_OPEN_ARROW',
    CLOSED_ARROW: 'CLOSED_ARROW',
    R_CLOSED_ARROW: 'R_CLOSED_ARROW',
    BUTT: 'BUTT',
    SQUARE: 'SQUARE',
    DIAMOND: 'DIAMOND',
    CIRCLE: 'CIRCLE',
    SLASH: 'SLASH',
  },
}

export default Annotations;