import Rect from './Rect';

/**
 * Represents a utility class used to manipulate quadrilateral objects.
 * @memberof Core.Math
 */
class Quad {

  /**
   * Create a new Quad with the x and y coordinates of the the four points of a quadrilateral.
   * @param {number} x1 - the x coordinate of the lower-left point
   * @param {number} y1 - the y coordinate of the lower-left point
   * @param {number} x2 - the x coordinate of the lower-right point
   * @param {number} y2 - the y coordinate of the lower-right point
   * @param {number} x3 - the x coordinate of the upper-right point
   * @param {number} y3 - the y coordinate of the upper-right point
   * @param {number} x4 - the x coordinate of the upper-left point
   * @param {number} y4 - the y coordinate of the upper-left point
   * 
   * @property {number} x1 - the x coordinate of the lower-left point
   * @property {number} y1 - the y coordinate of the lower-left point
   * @property {number} x2 - the x coordinate of the lower-right point
   * @property {number} y2 - the y coordinate of the lower-right point
   * @property {number} x3 - the x coordinate of the upper-right point
   * @property {number} y3 - the y coordinate of the upper-right point
   * @property {number} x4 - the x coordinate of the upper-left point
   * @property {number} y4 - the y coordinate of the upper-left point
   * 
   * @example
(x4,y4)---(x3,y3)
  |        |
(x1,y1)---(x2,y2)
   */
  constructor(x1, y1, x2, y2, x3, y3, x4, y4) {
    this.x1 = x1;
    this.y1 = y1;
    this.x2 = x2;
    this.y2 = y2;
    this.x3 = x3;
    this.y3 = y3;
    this.x4 = x4;
    this.y4 = y4;
  }

  /**
   * Returns a Rect that represents this quad.
   * @return {Core.Math.Rect} A rect that represents this quad
   */
  toRect() {
    return new Rect(this.x4, this.y4, this.x2, this.y2);
  }
}

export default Quad;
