import { describe, it, expect } from 'vitest'
import PriorityQueue from '../PriorityQueue'

describe('PriorityQueue', () => {
  const comparator = (a: number, b: number) => a - b

  it('should initialize with given values', () => {
    const pq = new PriorityQueue({ comparator, initialValues: [3, 1, 2] })
    expect(pq.size()).toBe(3)
    expect(pq.peek()).toBe(1)
  })

  it('should queue elements correctly', () => {
    const pq = new PriorityQueue({ comparator })
    pq.queue(3)
    pq.queue(1)
    pq.queue(2)
    expect(pq.size()).toBe(3)
    expect(pq.peek()).toBe(1)
  })

  it('should dequeue elements correctly', () => {
    const pq = new PriorityQueue({ comparator, initialValues: [3, 1, 2] })
    expect(pq.dequeue()).toBe(1)
    expect(pq.size()).toBe(2)
    expect(pq.peek()).toBe(2)
  })

  it('should find elements correctly', () => {
    const pq = new PriorityQueue({ comparator, initialValues: [3, 1, 2] })
    expect(pq.find(2)).toBe(1)
    expect(pq.find(4)).toBe(-1)
  })

  it('should remove elements correctly', () => {
    const pq = new PriorityQueue({ comparator, initialValues: [3, 1, 2] })
    expect(pq.remove(2)).toBe(true)
    expect(pq.size()).toBe(2)
    expect(pq.find(2)).toBe(-1)
  })

  it('should remove all matching elements correctly', () => {
    const pq = new PriorityQueue({ comparator, initialValues: [3, 1, 2, 2] })
    const removed = pq.removeAllMatching((value: number) => value === 2, (value: number) => {
      console.log(`Removed: ${value}`)
    })
    expect(removed).toBe(2)
    expect(pq.size()).toBe(2)
    expect(pq.find(2)).toBe(-1)
  })

  it('should check if the queue is empty', () => {
    const pq = new PriorityQueue({ comparator })
    expect(pq.isEmpty()).toBe(true)
    pq.queue(1)
    expect(pq.isEmpty()).toBe(false)
  })

  it('should return the correct size of the queue', () => {
    const pq = new PriorityQueue({ comparator })
    expect(pq.size()).toBe(0)
    pq.queue(1)
    expect(pq.size()).toBe(1)
  })
})
