import { describe, it, expect, vi } from 'vitest'
import TaskQueue from '../TaskQueue'

describe('TaskQueue', () => {
  it('should add a task and return a task ID', () => {
    const taskQueue = new TaskQueue()
    const callback = vi.fn()
    const taskId = taskQueue.addTask(callback)

    expect(taskId).toBe(1)
    expect(taskQueue['taskQueue'][taskId]).toBeDefined()
    expect(taskQueue['taskQueue'][taskId].callback).toBe(callback)
  })

  it('should execute a task immediately if not running', () => {
    const taskQueue = new TaskQueue()
    const callback = vi.fn()
    taskQueue.addTask(callback)

    expect(callback).toHaveBeenCalled()
  })

  it('should execute tasks in order', () => {
    const taskQueue = new TaskQueue()
    const results: number[] = []
    const callback1 = () => results.push(1)
    const callback2 = () => results.push(2)

    taskQueue.addTask(callback1)
    taskQueue.addTask(callback2)

    expect(results).toEqual([1, 2])
  })

  it('should handle tasks with arguments', () => {
    const taskQueue = new TaskQueue()
    const callback = vi.fn()
    taskQueue.addTask(callback, 'arg1', 'arg2')

    expect(callback).toHaveBeenCalledWith('arg1', 'arg2')
  })

  it('should delete a task after execution', () => {
    const taskQueue = new TaskQueue()
    const callback = vi.fn()
    const taskId = taskQueue.addTask(callback)

    expect(taskQueue['taskQueue'][taskId]).toBeDefined()
    expect(callback).toHaveBeenCalled()
    expect(taskQueue['taskQueue'][taskId]).toBeUndefined()
  })

  it('should not execute a task if already running', () => {
    const taskQueue = new TaskQueue()
    const callback1 = vi.fn()
    const callback2 = vi.fn()

    taskQueue.addTask(callback1)
    taskQueue.addTask(callback2)

    expect(callback1).toHaveBeenCalled()
    expect(callback2).toHaveBeenCalled()
  })
})
